/*
    *
    * This file is a part of CoreStats.
    * A real time system resource viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once

#include <QtGui>
#include <QtCore>
#include <QtWidgets>

/*
    *
    * UsageBar class
    *
    * UsageBar is designed to show the current usage of various system resources
    * like CPU, RAM, Swap, Network etc.
    *
    * A single UsageBar can show data in multiple segments: 4 segments for quad
    * core CPU, two segments for Network Up and Down, and so on
    *
*/

typedef QList<quint64> ResourceValues;

class UsageBar : public QWidget {
	Q_OBJECT

public:
    enum Units {
        PERCENT = 0x218628,     // Percentage
        SIZE,                   // Size, like KiB, TiB, etc
        SPEED                   // Speed, like MiB/s
    };

    UsageBar(QString resource, int segments, QWidget *parent);

    /* Maximum value */
    void setMax(quint64 max);

    /* Units */
    void setUnits(UsageBar::Units units);

    /* Set the bar value */
    void setValues(ResourceValues);

    QSize sizeHint();
    QSize minimumSizeHint();

    int minimumWidth();

private:
    int mSegments;
    UsageBar::Units mUnits;
    QString resName;

    quint64 mMax;
    quint64 minWidth;

    ResourceValues mValues;

protected:
    void paintEvent(QPaintEvent *);
};
